@@ -394,6 +394,18 @@ void pfshdrcalibrate( int argc, char* argv[] )
       // that is assume aperture=1 and sensitivity=1
       float exp_time = 1.0f / powf(2.0f,atof( exp_str ));
 
+      float iso = 100.f;      
+      const char* iso_str = 
+	frame -> getTags() -> getString("ISO");
+      if( iso_str != NULL )
+        iso = atof( iso_str );      
+
+      float raw_exposure_time = 1.f;      
+      const char* etime_str = 
+	frame -> getTags() -> getString("exposure_time");
+      if( etime_str != NULL )
+        raw_exposure_time = atof( etime_str );      
+
       // absolute calibration: this magic multiplier is a result of my
       // research in internet plus a bit of tweaking with a luminance
       // meter. tested with canon 350d, so might be a bit off for other
@@ -413,7 +425,9 @@ void pfshdrcalibrate( int argc, char* argv[] )
 	{
 	  
 	  Exposure eY;
-	  eY.ti = exp_time;
+	  eY.ti = exp_time;          
+          eY.exposure_time = raw_exposure_time;          
+          eY.iso = iso;          
 	  eY.yi = new pfs::Array2DImpl( width, height );
 	  
 	  if( eY.yi == NULL )
@@ -446,6 +460,8 @@ void pfshdrcalibrate( int argc, char* argv[] )
 	
 	Exposure eR,eG,eB;
 	eR.ti = eG.ti = eB.ti = exp_time;
+	eR.iso = eG.iso = eB.iso = iso;
+        eR.exposure_time = eG.exposure_time = eB.exposure_time = raw_exposure_time;          
 	eR.yi = new pfs::Array2DImpl( width, height );
 	eG.yi = new pfs::Array2DImpl( width, height );
 	eB.yi = new pfs::Array2DImpl( width, height );
@@ -523,6 +539,7 @@ void pfshdrcalibrate( int argc, char* argv[] )
   /* 1.4: currently, weights are always Gaussian */
   /* Composite function works better for extreme cases */
   weightsComposite ( w, M, opt_minresponse, opt_maxresponse, opt_gauss );
+  
 //   weightsGauss( w, M, opt_minresponse, opt_maxresponse, opt_gauss );
 
   // camera response functions for each channel
@@ -630,7 +647,8 @@ void pfshdrcalibrate( int argc, char* argv[] )
 	  VERBOSE_STR << "interpolated " << perc << "% of the Y response curve..." << endl;
 	}
       else
-	{
+	{          
+          
 	  int numr   = responseFillGaps ( Ir, w, M );
 	  int numg   = responseFillGaps ( Ig, w, M );
 	  int numb   = responseFillGaps ( Ib, w, M );
