@@ -41,6 +41,7 @@
 
 #include <pfs.h>
 
+#include <config.h>
 
 static pfs::ColorSpace findColorSpace( const char *name );
 
@@ -71,7 +72,7 @@ void mexFunction(int nlhs, mxArray *plhs[],
         pfs::ColorSpace outCS = findColorSpace( get_mex_string( prhs[nrhs-1] ) );
 
         const mwSize *in_dim = mxGetDimensions( prhs[1] );
-        const int rows = in_dim[0], cols = in_dim[1];
+        const int rows = (int)in_dim[0], cols = (int)in_dim[1];
 
 //		printf( "%d x %d\n", rows, cols );
         
