@@ -30,7 +30,9 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <fcntl.h>
-#include <unistd.h>
+
+#include <config.h>
+
 #include <sys/stat.h>
 
 #include "mex.h"
